
``selkie.com`` — Shell and command line
=======================================

.. automodule:: selkie.com

.. autofunction:: file_size
.. autofunction:: wget
.. autodata:: more

Shell calls
-----------

.. autofunction:: system
.. autofunction:: backtick
.. autofunction:: run_command
.. autofunction:: strip_escapes

Command-line processing
-----------------------

.. autoclass:: Shift
.. autoclass:: Main
